require('colors')
const fs = require('fs')
const { string2camel } = require('../tools')
const templates = require('../templates')
const componentName = process.argv[2]
const componentCamelName = string2camel(componentName)

if (!componentName) {
  console.error('Please supply a valid component name'.red)
  process.exit(1)
}

if (componentName.match(/[A-Z]/)) {
  console.error('Git is not case-sensitive so use lowercase consistently'.red)
  process.exit(1)
}

console.log('Creating Component Templates with name: ' + componentName)

const componentDirectory = `./src/components/${componentName}`

if (fs.existsSync(componentDirectory)) {
  console.error(`Component ${componentName} already exists.`.red)
  process.exit(1)
}

fs.mkdirSync(componentDirectory)

const generatedTemplates = templates.map((template) => template(componentName, componentCamelName))

generatedTemplates.forEach((template) => {
  if (template.main) {
    fs.writeFileSync(
      `${componentDirectory}/index${template.extension}`,
      template.content
    )
  } else {
    fs.writeFileSync(
      `${componentDirectory}/${componentName}${template.extension}`,
      template.content
    )
  }
})

const indexText = fs.readFileSync('./src/index.js', 'utf8')
const replaceText = indexText.replace('// import pleaceholder don’t remove', `// import pleaceholder don’t remove\nimport ${componentCamelName} from './components/${componentName}/index.ts';`)
const lastText = replaceText.replace('// export pleaceholder don’t remove', `// export pleaceholder don’t remove\n\t${componentCamelName},`)
fs.writeFileSync('./src/index.js', lastText, 'utf8')

console.log(
  'Successfully created component under: ' + componentDirectory.green
)
